.. _python:

Python
======

The python reference guide for Rubrix. This section contains:

* :ref:`python_client`: The base client module
* :ref:`python_metrics`: The module for dataset metrics
* :ref:`python_labeling`: A toolbox to enhance your labeling workflow (weak labels, noisy labels, etc.)

.. toctree::
   :maxdepth: 2
   :caption: Reference
   :hidden:

   python_client
   python_metrics
   python_labeling
